-- admin table - Queue for admin tasks sent from front-end for back-end processing.
-- $Id: admin.sql,v 1.4 2006/01/16 00:17:54 maxbaker Exp $ 

DROP TABLE admin;
DROP SEQUENCE admin_job_seq;

CREATE TABLE admin (
    job         serial,
    entered     TIMESTAMP DEFAULT now(),
    started     TIMESTAMP,
    finished    TIMESTAMP,
    device      inet,
    port        text,
    action      text, -- delete, delete+nodes, macsuck, arpnip, refresh, vlan
    subaction   text, -- free field to be used for each action
    status      text, -- queued, running, done, error, del
    username    text,
    userip      inet,
    log         text,
    debug       boolean
                   );
-- $Id: device.sql,v 1.7 2004/02/07 07:27:43 maxbaker Exp $

DROP TABLE device;

CREATE TABLE device (
    ip           inet PRIMARY KEY,
    creation     TIMESTAMP DEFAULT now(),
    dns          text,
    description  text,
    uptime       bigint,
    contact      text,
    name         text,
    location     text,
    layers       varchar(8),
    ports        integer,
    mac          macaddr,
    serial       text,
    model        text,
    ps1_type     text,
    ps2_type     text,
    ps1_status   text,
    ps2_status   text,
    fan          text,
    slots        integer,
    vendor       text,      
    os           text,
    os_ver       text,
    log          text,      -- HP Devices can store their log in here.
    snmp_ver     integer,   -- Holds the SNMP Version of device 
    snmp_comm    text,      -- Holds the SNMP Community String
    vtp_domain   text,
    last_discover TIMESTAMP,
    last_macsuck  TIMESTAMP,
    last_arpnip   TIMESTAMP
);

-- Indexing for speed-ups
CREATE INDEX idx_device_dns    ON device(dns);
CREATE INDEX idx_device_layers ON device(layers);
CREATE INDEX idx_device_vendor ON device(vendor);
CREATE INDEX idx_device_model  ON device(model);
-- $Id: device_ip.sql,v 1.2 2003/02/14 20:58:30 max Exp $

DROP TABLE device_ip;

CREATE TABLE device_ip (
    ip          inet,
    alias       inet,
    port        text,
    dns         text,
    creation    TIMESTAMP DEFAULT now(),
    PRIMARY KEY(ip,alias)
);

-- Indexing for speed ups
CREATE INDEX idx_device_ip_ip      ON device_ip(ip);
CREATE INDEX idx_device_ip_alias   ON device_ip(alias);
CREATE INDEX idx_device_ip_ip_port ON device_ip(ip,port);
-- $Id: device_port.sql,v 1.6 2004/09/15 03:41:29 maxbaker Exp $

DROP TABLE device_port;

CREATE TABLE device_port (
    ip          inet,   -- ip of device
    port        text,   -- Unique identifier of Physical Port Name
    creation    TIMESTAMP DEFAULT now(),
    descr       text,   -- Description of Port 
    up          text,   -- Current Link Status
    up_admin    text,   -- Admin Link Status
    type        text,   -- Description of Port Media Type
    duplex      text,   -- Current Duplex Setting
    duplex_admin text,  -- Admin Duplex Setting
    speed       text, 
    name        text,   -- Human Set name
    mac         macaddr,-- MAC of the switch port
    mtu         integer,
    stp         text,   -- Spanning Tree Protocol Status
    remote_ip   inet,   -- Neighboring device connected to
    remote_port text,   -- Neighboring port connected to
    remote_type text,   -- Type of device connected to
    remote_id   text,   -- remote ID string of neighbor
    vlan        text,   -- VLAN port connected to
    lastchange  bigint, -- Last time the port went up or down
    PRIMARY KEY(port,ip) 
);

CREATE INDEX idx_device_port_ip ON device_port(ip);
CREATE INDEX idx_device_port_remote_ip ON device_port(remote_ip);
-- For the duplex mismatch finder :
CREATE INDEX idx_device_port_ip_port_duplex ON device_port(ip,port,duplex);
CREATE INDEX idx_device_port_ip_up_admin ON device_port(ip,up_admin);
CREATE INDEX idx_device_port_mac ON device_port(mac);
-- $Id: device_port_log.sql,v 1.4 2003/03/21 00:40:01 max Exp $

DROP TABLE device_port_log;
DROP SEQUENCE device_port_log_id_seq;

CREATE TABLE device_port_log (
    id          serial, 
    ip          inet,
    port        text,
    reason      text,
    log         text, 
    username    text,   -- user is a reserved word
    userip      inet,
    action      text,
    creation    TIMESTAMP DEFAULT now()
                             );

CREATE INDEX idx_device_port_log_1 ON device_port_log(ip,port);
CREATE INDEX idx_device_port_log_user ON device_port_log(username);
-- $Id: device_port_ssid.sql,v 1.1 2006/04/04 22:55:52 fenner Exp $

DROP TABLE device_port_ssid;

CREATE TABLE device_port_ssid (
    ip          inet,   -- ip of device
    port        text,   -- Unique identifier of Physical Port Name
    ssid        text,   -- An SSID that is valid on this port.
    broadcast   boolean,-- Is it broadcast?
    channel     integer -- 802.11 channel number
);

CREATE INDEX idx_device_port_ssid_ip_port ON device_port_ssid(ip,port);
-- $Id: log.sql,v 1.3 2004/11/09 20:06:16 maxbaker Exp $

DROP TABLE log;
DROP SEQUENCE log_id_seq;

CREATE TABLE log (
    id          serial,
    creation    TIMESTAMP DEFAULT now(),
    class       text,
    entry       text,
    logfile     text
);
-- $Id: node.sql,v 1.4 2006/04/04 22:55:52 fenner Exp $

DROP TABLE node;

CREATE TABLE node (
    mac         macaddr,
    switch      inet,
    port        text,
    active      boolean,
    oui         varchar(8),  -- fe:9a:57
    time_first  timestamp default now(),
    time_recent timestamp default now(),
    time_last   timestamp default now(),
    PRIMARY KEY(mac,switch,port) 
);

-- Indexes speed things up a LOT
CREATE INDEX idx_node_switch_port_active ON node(switch,port,active);
CREATE INDEX idx_node_switch_port ON node(switch,port);
CREATE INDEX idx_node_switch      ON node(switch);
CREATE INDEX idx_node_mac         ON node(mac);
CREATE INDEX idx_node_mac_active  ON node(mac,active);
-- CREATE INDEX idx_node_oui         ON node(oui);
-- $Id: node_ip.sql,v 1.3 2003/02/18 19:05:12 max Exp $

DROP TABLE node_ip;

CREATE TABLE node_ip (
    mac         macaddr,
    ip          inet,
    active      boolean,
    time_first  timestamp default now(),
    time_last   timestamp default now(),
    PRIMARY KEY(mac,ip)
);

-- Indexing speed ups.
CREATE INDEX idx_node_ip_ip          ON node_ip(ip);
CREATE INDEX idx_node_ip_mac         ON node_ip(mac);
CREATE INDEX idx_node_ip_mac_active  ON node_ip(mac,active);
-- $Id: node_nbt.sql,v 1.2 2004/11/01 05:02:43 maxbaker Exp $
-- node_nbt - Hold Netbios information for each node.

DROP TABLE node_nbt;

CREATE TABLE node_nbt (
    mac         macaddr PRIMARY KEY,
    ip          inet,
    nbname      text,
    domain      text,
    server      boolean,
    nbuser      text,
    active      boolean,    -- do we need this still?
    time_first  timestamp default now(),
    time_last   timestamp default now()
);

-- Indexing speed ups.
CREATE INDEX idx_node_nbt_mac         ON node_nbt(mac);
CREATE INDEX idx_node_nbt_nbname      ON node_nbt(nbname);
CREATE INDEX idx_node_nbt_domain      ON node_nbt(domain);
CREATE INDEX idx_node_nbt_mac_active  ON node_nbt(mac,active);
-- $Id: oui.sql,v 1.3 2003/03/21 00:40:51 max Exp $

DROP TABLE oui;

CREATE TABLE oui (
    oui         varchar(8) PRIMARY KEY,
    company     text
);

-- $Id: sessions.sql,v 1.3 2003/02/27 18:46:31 max Exp $

DROP TABLE sessions;

CREATE TABLE sessions (
    id          char(32) NOT NULL PRIMARY KEY,
    creation    TIMESTAMP DEFAULT now(),
    a_session   text
                       );
-- $Id: subnets.sql,v 1.1 2005/03/21 03:47:48 jeneric Exp $

DROP TABLE subnets;

CREATE TABLE subnets (
    net cidr NOT NULL,
    creation timestamp default now(),
    last_discover timestamp default now(),
    PRIMARY KEY(net)
);
-- $Id: user_log.sql,v 1.1 2004/09/25 03:54:32 maxbaker Exp $
-- This table logs login and logout / change requests for users

DROP TABLE user_log;
DROP SEQUENCE user_log_entry_seq;

CREATE TABLE user_log (
    entry           serial,
    username        varchar(50),
    userip          inet,
    event           text,
    details         text,
    creation        TIMESTAMP DEFAULT now()
                      );
-- $Id: users.sql,v 1.3 2004/03/20 02:45:45 maxbaker Exp $

DROP TABLE users;

CREATE TABLE users (
    username        varchar(50) PRIMARY KEY,
    password        text,   -- md5 
    creation        TIMESTAMP DEFAULT now(),
    last_on         TIMESTAMP,
    port_control    boolean DEFAULT false,
    admin           boolean DEFAULT false,
    fullname        text,
    note            text
                    );
